Class: Google::Apis::IapV1::AccessSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iap_v1/classes.rb,
lib/google/apis/iap_v1/representations.rb,
lib/google/apis/iap_v1/representations.rb

Overview

Access related settings for IAP protected apps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AccessSettings

Returns a new instance of AccessSettings.



118
119
120
# File 'lib/google/apis/iap_v1/classes.rb', line 118

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_domains_settingsGoogle::Apis::IapV1::AllowedDomainsSettings

Configuration for IAP allowed domains. Lets you to restrict access to an app and allow access to only the domains that you list. Corresponds to the JSON property allowedDomainsSettings



71
72
73
# File 'lib/google/apis/iap_v1/classes.rb', line 71

def allowed_domains_settings
  @allowed_domains_settings
end

#cors_settingsGoogle::Apis::IapV1::CorsSettings

Allows customers to configure HTTP request paths that'll allow HTTP OPTIONS call to bypass authentication and authorization. Corresponds to the JSON property corsSettings



77
78
79
# File 'lib/google/apis/iap_v1/classes.rb', line 77

def cors_settings
  @cors_settings
end

#gcip_settingsGoogle::Apis::IapV1::GcipSettings

Allows customers to configure tenant IDs for a Cloud Identity Platform (GCIP) instance for each application. Corresponds to the JSON property gcipSettings



83
84
85
# File 'lib/google/apis/iap_v1/classes.rb', line 83

def gcip_settings
  @gcip_settings
end

#identity_sourcesArray<String>

Optional. Identity sources that IAP can use to authenticate the end user. Only one identity source can be configured. Corresponds to the JSON property identitySources

Returns:

  • (Array<String>)


89
90
91
# File 'lib/google/apis/iap_v1/classes.rb', line 89

def identity_sources
  @identity_sources
end

#oauth_settingsGoogle::Apis::IapV1::OAuthSettings

Configuration for OAuth login&consent flow behavior as well as for OAuth Credentials. Corresponds to the JSON property oauthSettings



95
96
97
# File 'lib/google/apis/iap_v1/classes.rb', line 95

def oauth_settings
  @oauth_settings
end

#policy_delegation_settingsGoogle::Apis::IapV1::PolicyDelegationSettings

PolicyDelegationConfig allows google-internal teams to use IAP for apps hosted in a tenant project. Using these settings, the app can delegate permission check to happen against the linked customer project. This is only ever supposed to be used by google internal teams, hence the restriction on the proto. Corresponds to the JSON property policyDelegationSettings



104
105
106
# File 'lib/google/apis/iap_v1/classes.rb', line 104

def policy_delegation_settings
  @policy_delegation_settings
end

#reauth_settingsGoogle::Apis::IapV1::ReauthSettings

Configuration for IAP reauthentication policies. Corresponds to the JSON property reauthSettings



109
110
111
# File 'lib/google/apis/iap_v1/classes.rb', line 109

def reauth_settings
  @reauth_settings
end

#workforce_identity_settingsGoogle::Apis::IapV1::WorkforceIdentitySettings

WorkforceIdentitySettings allows customers to configure workforce pools and OAuth 2.0 settings to gate their applications using a third-party IdP with access control. Corresponds to the JSON property workforceIdentitySettings



116
117
118
# File 'lib/google/apis/iap_v1/classes.rb', line 116

def workforce_identity_settings
  @workforce_identity_settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



123
124
125
126
127
128
129
130
131
132
# File 'lib/google/apis/iap_v1/classes.rb', line 123

def update!(**args)
  @allowed_domains_settings = args[:allowed_domains_settings] if args.key?(:allowed_domains_settings)
  @cors_settings = args[:cors_settings] if args.key?(:cors_settings)
  @gcip_settings = args[:gcip_settings] if args.key?(:gcip_settings)
  @identity_sources = args[:identity_sources] if args.key?(:identity_sources)
  @oauth_settings = args[:oauth_settings] if args.key?(:oauth_settings)
  @policy_delegation_settings = args[:policy_delegation_settings] if args.key?(:policy_delegation_settings)
  @reauth_settings = args[:reauth_settings] if args.key?(:reauth_settings)
  @workforce_identity_settings = args[:workforce_identity_settings] if args.key?(:workforce_identity_settings)
end