Class: Google::Apis::IapV1::AllowedDomainsSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iap_v1/classes.rb,
lib/google/apis/iap_v1/representations.rb,
lib/google/apis/iap_v1/representations.rb

Overview

Configuration for IAP allowed domains. Lets you to restrict access to an app and allow access to only the domains that you list.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AllowedDomainsSettings

Returns a new instance of AllowedDomainsSettings.



151
152
153
# File 'lib/google/apis/iap_v1/classes.rb', line 151

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#domainsArray<String>

Optional. List of trusted domains. Corresponds to the JSON property domains

Returns:

  • (Array<String>)


143
144
145
# File 'lib/google/apis/iap_v1/classes.rb', line 143

def domains
  @domains
end

#enableBoolean Also known as: enable?

Optional. Configuration for customers to opt in for the feature. Corresponds to the JSON property enable

Returns:

  • (Boolean)


148
149
150
# File 'lib/google/apis/iap_v1/classes.rb', line 148

def enable
  @enable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



156
157
158
159
# File 'lib/google/apis/iap_v1/classes.rb', line 156

def update!(**args)
  @domains = args[:domains] if args.key?(:domains)
  @enable = args[:enable] if args.key?(:enable)
end