Class: Google::Apis::IapV1::OAuthSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iap_v1/classes.rb,
lib/google/apis/iap_v1/representations.rb,
lib/google/apis/iap_v1/representations.rb

Overview

Configuration for OAuth login&consent flow behavior as well as for OAuth Credentials.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OAuthSettings

Returns a new instance of OAuthSettings.



832
833
834
# File 'lib/google/apis/iap_v1/classes.rb', line 832

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_idString

Optional. OAuth 2.0 client ID used in the OAuth flow to generate an access token. If this field is set, you can skip obtaining the OAuth credentials in this step: https://developers.google.com/identity/protocols/OAuth2?hl=en_US#1.- obtain-oauth-2.0-credentials-from-the-google-api-console. However, this could allow for client sharing. The risks of client sharing are outlined here: https: //cloud.google.com/iap/docs/sharing-oauth-clients#risks. Corresponds to the JSON property clientId

Returns:

  • (String)


806
807
808
# File 'lib/google/apis/iap_v1/classes.rb', line 806

def client_id
  @client_id
end

#client_secretString

Optional. Input only. OAuth secret paired with client ID Corresponds to the JSON property clientSecret

Returns:

  • (String)


811
812
813
# File 'lib/google/apis/iap_v1/classes.rb', line 811

def client_secret
  @client_secret
end

#client_secret_sha256String

Output only. OAuth secret sha256 paired with client ID Corresponds to the JSON property clientSecretSha256

Returns:

  • (String)


816
817
818
# File 'lib/google/apis/iap_v1/classes.rb', line 816

def client_secret_sha256
  @client_secret_sha256
end

#login_hintString

Domain hint to send as hd=? parameter in OAuth request flow. Enables redirect to primary IDP by skipping Google's login screen. https://developers.google. com/identity/protocols/OpenIDConnect#hd-param Note: IAP does not verify that the id token's hd claim matches this value since access behavior is managed by IAM policies. Corresponds to the JSON property loginHint

Returns:

  • (String)


825
826
827
# File 'lib/google/apis/iap_v1/classes.rb', line 825

def 
  @login_hint
end

#programmatic_clientsArray<String>

Optional. List of client ids allowed to use IAP programmatically. Corresponds to the JSON property programmaticClients

Returns:

  • (Array<String>)


830
831
832
# File 'lib/google/apis/iap_v1/classes.rb', line 830

def programmatic_clients
  @programmatic_clients
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



837
838
839
840
841
842
843
# File 'lib/google/apis/iap_v1/classes.rb', line 837

def update!(**args)
  @client_id = args[:client_id] if args.key?(:client_id)
  @client_secret = args[:client_secret] if args.key?(:client_secret)
  @client_secret_sha256 = args[:client_secret_sha256] if args.key?(:client_secret_sha256)
  @login_hint = args[:login_hint] if args.key?(:login_hint)
  @programmatic_clients = args[:programmatic_clients] if args.key?(:programmatic_clients)
end