Class: Google::Apis::IapV1::PolicyName

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iap_v1/classes.rb,
lib/google/apis/iap_v1/representations.rb,
lib/google/apis/iap_v1/representations.rb

Overview

An internal name for an IAM policy, based on the resource to which the policy applies. Not to be confused with a resource's external full resource name. For more information on this distinction, see go/iam-full-resource-names.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PolicyName

Returns a new instance of PolicyName.



1009
1010
1011
# File 'lib/google/apis/iap_v1/classes.rb', line 1009

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Identifies an instance of the type. ID format varies by type. The ID format is defined in the IAM .service file that defines the type, either in path_mapping or in a comment. Corresponds to the JSON property id

Returns:

  • (String)


992
993
994
# File 'lib/google/apis/iap_v1/classes.rb', line 992

def id
  @id
end

#regionString

For Cloud IAM: The location of the Policy. Must be empty or "global" for Policies owned by global IAM. Must name a region from prodspec/cloud-iam- cloudspec for Regional IAM Policies, see go/iam-faq#where-is-iam-currently- deployed. For Local IAM: This field should be set to "local". Corresponds to the JSON property region

Returns:

  • (String)


1000
1001
1002
# File 'lib/google/apis/iap_v1/classes.rb', line 1000

def region
  @region
end

#typeString

Resource type. Types are defined in IAM's .service files. Valid values for type might be 'storage_buckets', 'compute_instances', ' resourcemanager_customers', 'billing_accounts', etc. Corresponds to the JSON property type

Returns:

  • (String)


1007
1008
1009
# File 'lib/google/apis/iap_v1/classes.rb', line 1007

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1014
1015
1016
1017
1018
# File 'lib/google/apis/iap_v1/classes.rb', line 1014

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @region = args[:region] if args.key?(:region)
  @type = args[:type] if args.key?(:type)
end