Class: Google::Apis::IapV1::ReauthSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iap_v1/classes.rb,
lib/google/apis/iap_v1/representations.rb,
lib/google/apis/iap_v1/representations.rb

Overview

Configuration for IAP reauthentication policies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReauthSettings

Returns a new instance of ReauthSettings.



1040
1041
1042
# File 'lib/google/apis/iap_v1/classes.rb', line 1040

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_ageString

Optional. Reauth session lifetime, how long before a user has to reauthenticate again. Corresponds to the JSON property maxAge

Returns:

  • (String)


1026
1027
1028
# File 'lib/google/apis/iap_v1/classes.rb', line 1026

def max_age
  @max_age
end

#method_propString

Optional. Reauth method requested. Corresponds to the JSON property method

Returns:

  • (String)


1031
1032
1033
# File 'lib/google/apis/iap_v1/classes.rb', line 1031

def method_prop
  @method_prop
end

#policy_typeString

Optional. How IAP determines the effective policy in cases of hierarchical policies. Policies are merged from higher in the hierarchy to lower in the hierarchy. Corresponds to the JSON property policyType

Returns:

  • (String)


1038
1039
1040
# File 'lib/google/apis/iap_v1/classes.rb', line 1038

def policy_type
  @policy_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1045
1046
1047
1048
1049
# File 'lib/google/apis/iap_v1/classes.rb', line 1045

def update!(**args)
  @max_age = args[:max_age] if args.key?(:max_age)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @policy_type = args[:policy_type] if args.key?(:policy_type)
end