Class: Google::Apis::IapV1::GcipSettings
- Inherits:
-
Object
- Object
- Google::Apis::IapV1::GcipSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/iap_v1/classes.rb,
lib/google/apis/iap_v1/representations.rb,
lib/google/apis/iap_v1/representations.rb
Overview
Allows customers to configure tenant IDs for a Cloud Identity Platform (GCIP) instance for each application.
Instance Attribute Summary collapse
-
#login_page_uri ⇒ String
Login page URI associated with the GCIP tenants.
-
#tenant_ids ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GcipSettings
constructor
A new instance of GcipSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GcipSettings
Returns a new instance of GcipSettings.
535 536 537 |
# File 'lib/google/apis/iap_v1/classes.rb', line 535 def initialize(**args) update!(**args) end |
Instance Attribute Details
#login_page_uri ⇒ String
Login page URI associated with the GCIP tenants. Typically, all resources
within the same project share the same login page, though it could be
overridden at the sub resource level.
Corresponds to the JSON property loginPageUri
523 524 525 |
# File 'lib/google/apis/iap_v1/classes.rb', line 523 def login_page_uri @login_page_uri end |
#tenant_ids ⇒ Array<String>
Optional. GCIP tenant IDs that are linked to the IAP resource. tenant_ids
could be a string beginning with a number character to indicate authenticating
with GCIP tenant flow, or in the format of _ to indicate authenticating with
GCIP agent flow. If agent flow is used, tenant_ids should only contain one
single element, while for tenant flow, tenant_ids can contain multiple
elements.
Corresponds to the JSON property tenantIds
533 534 535 |
# File 'lib/google/apis/iap_v1/classes.rb', line 533 def tenant_ids @tenant_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
540 541 542 543 |
# File 'lib/google/apis/iap_v1/classes.rb', line 540 def update!(**args) @login_page_uri = args[:login_page_uri] if args.key?(:login_page_uri) @tenant_ids = args[:tenant_ids] if args.key?(:tenant_ids) end |